@@ -182,8 +182,8 @@
 /* #undef CHANNEL_TSMF */
 /* #undef CHANNEL_TSMF_CLIENT */
 /* #undef CHANNEL_TSMF_SERVER */
-#define CHANNEL_URBDRC
-#define CHANNEL_URBDRC_CLIENT
+/* #undef CHANNEL_URBDRC */
+/* #undef CHANNEL_URBDRC_CLIENT */
 /* #undef CHANNEL_URBDRC_SERVER */
 #define CHANNEL_VIDEO
 #define CHANNEL_VIDEO_CLIENT
